==> snipe-it-7.1.17.zip: snipe-it-7.1.17/tests/Feature/Accessories/Ui/ShowAccessoryTest.php <==
<?php

namespace Tests\Feature\Accessories\Ui;

use App\Models\Accessory;
use App\Models\Company;
use App\Models\User;
use Tests\TestCase;

class ShowAccessoryTest extends TestCase
{
    public function testRequiresPermissionToViewAccessory()
    {
        $this->actingAs(User::factory()->create())
            ->get(route('accessories.show', Accessory::factory()->create()->id))
            ->assertForbidden();
    }

    public function testCannotViewAccessoryFromAnotherCompany()
    {
        $this->settings->enableMultipleFullCompanySupport();

        [$companyA, $companyB] = Company::factory()->count(2)->create();
        $accessoryForCompanyA = Accessory::factory()->for($companyA)->create();
        $userForCompanyB = User::factory()->for($companyB)->viewAccessories()->create();

        $this->actingAs($userForCompanyB)
            ->get(route('accessories.show', $accessoryForCompanyA->id))
            ->assertForbidden();
    }

    public function testCanViewAccessory()
    {
        $accessory = Accessory::factory()->create();

        $this->actingAs(User::factory()->viewAccessories()->create())
            ->get(route('accessories.show', $accessory->id))
            ->assertOk()
            ->assertViewIs('accessories.view')
            ->assertViewHas(['accessory' => $accessory]);
    }
  
    public function testPageRenders()
    {
        $this->actingAs(User::factory()->superuser()->create())
            ->get(route('accessories.show', Accessory::factory()->create()->id))
            ->assertOk();

    }
}

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/tests/Feature/Accessories/Ui/ShowAccessoryTest.php <==
<?php

namespace Tests\Feature\Accessories\Ui;

use App\Models\Accessory;
use App\Models\Company;
use App\Models\User;
use Tests\TestCase;

class ShowAccessoryTest extends TestCase
{
    public function testRequiresPermissionToViewAccessory()
    {
        $this->actingAs(User::factory()->create())
            ->get(route('accessories.show', Accessory::factory()->create()))
            ->assertForbidden();
    }

    public function testCannotViewAccessoryFromAnotherCompany()
    {
        $this->settings->enableMultipleFullCompanySupport();

        [$companyA, $companyB] = Company::factory()->count(2)->create();
        $accessoryForCompanyA = Accessory::factory()->for($companyA)->create();
        $userForCompanyB = User::factory()->for($companyB)->viewAccessories()->create();

        $this->actingAs($userForCompanyB)
            ->get(route('accessories.show', $accessoryForCompanyA))
            ->assertStatus(302);
    }

    public function testCanViewAccessory()
    {
        $accessory = Accessory::factory()->create();

        $this->actingAs(User::factory()->viewAccessories()->create())
            ->get(route('accessories.show', $accessory))
            ->assertOk()
            ->assertViewIs('accessories.view')
            ->assertViewHas(['accessory' => $accessory]);
    }
  
    public function testPageRenders()
    {
        $this->actingAs(User::factory()->superuser()->create())
            ->get(route('accessories.show', Accessory::factory()->create()))
            ->assertOk();

    }
}
